package com.ghy.order.service;

import com.ghy.order.domain.OrderAssessLabel;

import java.util.List;

/**
 * 订单与评价标签关联关系Service接口
 *
 * @author ydq
 * @date : 2022-10-08 22:08
 */
public interface IOrderAssessLabelService {
    /**
     * 查询订单与评价标签关联关系
     *
     * @param id 订单与评价标签关联关系主键
     * @return 订单与评价标签关联关系
     */
    public OrderAssessLabel selectOrderAssessLabelById(Long id);

    /**
     * 查询订单与评价标签关联关系列表
     *
     * @param orderAssessLabel 订单与评价标签关联关系
     * @return 订单与评价标签关联关系集合
     */
    public List<OrderAssessLabel> selectOrderAssessLabelList(OrderAssessLabel orderAssessLabel);

    /**
     * 新增订单与评价标签关联关系
     *
     * @param orderAssessLabel 订单与评价标签关联关系
     * @return 结果
     */
    public int insertOrderAssessLabel(OrderAssessLabel orderAssessLabel);

    /**
     * 修改订单与评价标签关联关系
     *
     * @param orderAssessLabel 订单与评价标签关联关系
     * @return 结果
     */
    public int updateOrderAssessLabel(OrderAssessLabel orderAssessLabel);

    /**
     * 批量删除订单与评价标签关联关系
     *
     * @param ids 需要删除的订单与评价标签关联关系主键集合
     * @return 结果
     */
    public int deleteOrderAssessLabelByIds(String ids);

    /**
     * 删除订单与评价标签关联关系信息
     *
     * @param id 订单与评价标签关联关系主键
     * @return 结果
     */
    public int deleteOrderAssessLabelById(Long id);
}
